import envyaml
import os
import logging
from logging import Formatter, StreamHandler
import json

config = envyaml.EnvYAML(os.environ.get('CONFIG_PATH', 'config.yaml'))

def init() -> None:
    """
    Initializes the application and validates the config
    """

    initLogger()

    if config["app.scripts.path"] == "":
        logging.error("Scripts path not set")
        exit(1)
    elif config["app.scripts.path"][-1] != "/":
        logging.error("Scripts path does not end with a slash")
        exit(1)

def initLogger() -> None:
    """
    Initializes the logger
    """
    # style the logger output to look like uvicorn for root app
    FORMAT = '%(asctime)-15s %(levelname)s %(message)s'
    DATE_FORMAT = '%b %d %H:%M:%S'
    formatter = Formatter(fmt=FORMAT, datefmt=DATE_FORMAT)
    handler = StreamHandler()
    handler.setFormatter(formatter)
    logger = logging.getLogger()

    # remove default handler
    logger.handlers = []
    logger.addHandler(handler)

    logging.basicConfig(level=resolveLogLevel(config["app.log.level"]))

def resolveLogLevel(level: str) -> int:
    """
    Resolves a log level from a string
    """
    if level == 'debug':
        return logging.DEBUG
    elif level == 'info':
        return logging.INFO
    elif level == 'warning':
        return logging.WARNING
    elif level == 'error':
        return logging.ERROR
    elif level == 'critical':
        return logging.CRITICAL
    else:
        logging.warning("Invalid log level. Using INFO as default")
        return logging.INFO
