from fastapi import APIRouter, UploadFile, File
from config import config, resolveLogLevel
from uuid import uuid4
import magic
import logging

# set logging level
logging.basicConfig(level=resolveLogLevel(config["app.log.level"]))

router = APIRouter(
    prefix="/upload",
    tags=["upload"],
    responses={404: {"description": "Not found"}},
    )

@router.post("/")
async def upload(file: UploadFile):
    """
    Upload a python script to be stored
    """

    logging.debug(f"File name : {file.filename}")

    # Check if the file is a python script
    if not file.filename.endswith(".py"):
        return {"error": "File is not a python script"}

    logging.debug(f"File content type : {file.content_type}")

    if file.content_type != "text/x-python":
        return {"error": "File is not a python script"}

    # reset file pointer
    await file.seek(0)

    scriptDirectory = config["app.scripts.path"]

    # Get UUID file name
    uuid = uuid4()

    # Write the file to the script directory
    with open(scriptDirectory + str(uuid), "wb") as buffer:
        buffer.write(file.file.read())

    return {"uuid": str(uuid)}

